==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/InformalAttributeValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttributeValue;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.InstanceAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InstanceAttributeValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class InformalAttributeValueSetImpl extends InstanceSet<InformalAttributeValueSet,InformalAttributeValue> implements InformalAttributeValueSet {

    // attributes
    @Override
    public void setAv_ID( UniqueId ref_Av_ID ) throws XtumlException {
        for ( InformalAttributeValue informalattributevalue : this ) informalattributevalue.setAv_ID( ref_Av_ID );
    }


    // selections
    @Override
    public InstanceAttributeValueSet R948_is_a_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( InformalAttributeValue informalattributevalue : this ) instanceattributevalueset.add( informalattributevalue.R948_is_a_InstanceAttributeValue() );
        return instanceattributevalueset;
    }


    @Override
    public InformalAttributeValue nullElement() {
        return InformalAttributeValueImpl.EMPTY_INFORMALATTRIBUTEVALUE;
    }

    @Override
    public InformalAttributeValueSet emptySet() {
      return new InformalAttributeValueSetImpl();
    }

    @Override
    public InformalAttributeValueSet value() {
        return this;
    }

    @Override
    public List<InformalAttributeValue> elements() {
        return Arrays.asList(toArray(new InformalAttributeValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/interaction/impl/InformalAttributeValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.interaction.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttributeValue;
import io.ciera.tool.sql.ooaofooa.interaction.InformalAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.InstanceAttributeValueSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.InstanceAttributeValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class InformalAttributeValueSetImpl extends InstanceSet<InformalAttributeValueSet,InformalAttributeValue> implements InformalAttributeValueSet {

    public InformalAttributeValueSetImpl() {
    }

    public InformalAttributeValueSetImpl(Comparator<? super InformalAttributeValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAv_ID( UniqueId ref_Av_ID ) throws XtumlException {
        for ( InformalAttributeValue informalattributevalue : this ) informalattributevalue.setAv_ID( ref_Av_ID );
    }


    // selections
    @Override
    public InstanceAttributeValueSet R948_is_a_InstanceAttributeValue() throws XtumlException {
        InstanceAttributeValueSet instanceattributevalueset = new InstanceAttributeValueSetImpl();
        for ( InformalAttributeValue informalattributevalue : this ) instanceattributevalueset.add( informalattributevalue.R948_is_a_InstanceAttributeValue() );
        return instanceattributevalueset;
    }


    @Override
    public InformalAttributeValue nullElement() {
        return InformalAttributeValueImpl.EMPTY_INFORMALATTRIBUTEVALUE;
    }

    @Override
    public InformalAttributeValueSet emptySet() {
      return new InformalAttributeValueSetImpl();
    }

    @Override
    public InformalAttributeValueSet emptySet(Comparator<? super InformalAttributeValue> comp) {
      return new InformalAttributeValueSetImpl(comp);
    }

    @Override
    public InformalAttributeValueSet value() {
        return this;
    }

    @Override
    public List<InformalAttributeValue> elements() {
        return Arrays.asList(toArray(new InformalAttributeValue[0]));
    }

}
